@@ -76,6 +76,14 @@ test_that("factors coerced to characters, not integers", {
   expect_equal(out$v, c(1:3, letters[1:3]))
 })
 
+test_that("attributes of id variables are preserved", {
+  df <- data.frame(x = factor(1:3), y = 1:3, z = 3:1)
+  out <- gather(df, key, val, -x)
+
+  expect_equal(attributes(df$x), attributes(out$x))
+})
+
+
 test_that("common attributes are preserved", {
   df <- data.frame(date1 = Sys.Date(), date2 = Sys.Date() + 10)
   out <- gather(df, k, v)
