@@ -15,6 +15,12 @@ test_that("order doesn't matter", {
   expect_equal(one, two)
 })
 
+test_that("convert turns strings into integers", {
+  df <- dplyr::data_frame(key = "a", value = "1")
+  out <- spread(df, key, value, convert = TRUE)
+
+  expect_is(out$a, "integer")
+})
 
 test_that("duplicate values for one key is an error", {
   df <- data.frame(x = c("a", "b", "b"), y = c(1, 2, 2), z = c(1, 2, 2))
@@ -45,3 +51,17 @@ test_that("drop = FALSE keeps missing combinations (#25)", {
   expect_equal(out$a[2], 1)
 
 })
+
+test_that("preserve class of input", {
+  dat <- data.frame(
+    x = c("a", "a", "b", "b"),
+    y = c("c", "d", "c", "d"),
+    z = c("w", "x", "y", "z")
+  )
+  dat %>% (dplyr::tbl_df) %>% spread(x, z) %>% expect_is("tbl_df")
+
+  skip_if_not_installed("data.table")
+  dat %>% (dplyr::tbl_dt) %>% spread(x, z) %>% expect_is("tbl_dt")
+})
+
+
